@@ -10,6 +10,7 @@ import telethon.tl.custom
 from royalnet.typing import *
 
 from .dialog import Dialog
+from ..database import Telegram
 from ..database.base import Base
 
 log = logging.getLogger(__name__)
@@ -50,6 +51,18 @@ async def main():
 
     menus: Dict[int, Dialog] = {}
 
+    @bot.on(telethon.events.ChatAction())
+    async def on_chat_action(event: telethon.events.ChatAction.Event):
+        if event.user_joined:
+            users = await event.get_users()
+            chat = await event.get_chat()
+            assert len(users) == 1
+            user = users[0]
+            session = alchemist.Session()
+            tg = session.query(Telegram).filter_by(id=user.id).one_or_none()
+            if tg is None:
+                await bot.kick_participant(entity=chat, user=user)
+
     @bot.on(telethon.events.NewMessage())
     async def on_message(event: telethon.events.NewMessage.Event):
         msg: telethon.tl.custom.Message = event.message
@@ -62,6 +75,12 @@ async def main():
             await menu.next(msg)
         except StopAsyncIteration:
             del menus[msg.chat_id]
+        except Exception as e:
+            log.error(f"{e}")
+            bot.send_message(entity=msg.chat,
+                             message="☢️ Si è verificato un errore critico e la conversazione è stata annullata.\n"
+                                     "\n"
+                                     "L'errore è stato salvato nei log del server.")
 
     while True:
         log.info(f"Catching up...")
